==> hindent-5.2.7-82-x86_64.pkg.tar.xz: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hindent
version: 5.2.7
id: hindent-5.2.7-8j4GrYZxhZzJbbVZzGD4sf
key: hindent-5.2.7-8j4GrYZxhZzJbbVZzGD4sf
license: BSD-3-Clause
copyright: 2014 Chris Done, 2015 Andrew Gibiansky
maintainer: chrisdone@gmail.com
author: Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker
stability: Unstable
homepage: https://github.com/commercialhaskell/hindent
synopsis: Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.
    .
    See the Github page for usage\/explanation: <https://github.com/commercialhaskell/hindent>
category: Development
abi: 816900968ac021a426c8223da1ef1d47
exposed: True
exposed-modules:
    HIndent HIndent.CabalFile HIndent.Pretty HIndent.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/hindent-5.2.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/hindent-5.2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hindent
hs-libraries: HShindent-5.2.7-8j4GrYZxhZzJbbVZzGD4sf
depends:
    Cabal-2.4.0.1 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    directory-1.3.3.0 exceptions-0.10.1-7EeRXpdm0c5D9yRsXefkxH
    filepath-1.4.2.1 haskell-src-exts-1.21.0-CTGpg8A5DVxDxwCwFjhKVU
    monad-loops-0.4.3-EUyUG8IgG57IqzUQzuXocA mtl-2.2.2 text-1.2.3.1
    transformers-0.5.6.2 utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    yaml-0.11.0.0-A2ufaysmQBG6sOmrU4vFft
haddock-interfaces: /usr/share/doc/hindent/html/hindent.haddock
haddock-html: /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hindent-5.2.7-83-x86_64.pkg.tar.xz: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hindent
version: 5.2.7
id: hindent-5.2.7-B8ATKLLKjvhBS5pho944CZ
key: hindent-5.2.7-B8ATKLLKjvhBS5pho944CZ
license: BSD-3-Clause
copyright: 2014 Chris Done, 2015 Andrew Gibiansky
maintainer: chrisdone@gmail.com
author: Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker
stability: Unstable
homepage: https://github.com/commercialhaskell/hindent
synopsis: Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.
    .
    See the Github page for usage\/explanation: <https://github.com/commercialhaskell/hindent>
category: Development
abi: e377b18050cc1223be336557a582a3c1
exposed: True
exposed-modules:
    HIndent HIndent.CabalFile HIndent.Pretty HIndent.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/hindent-5.2.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/hindent-5.2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hindent
hs-libraries: HShindent-5.2.7-B8ATKLLKjvhBS5pho944CZ
depends:
    Cabal-2.4.0.1 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    directory-1.3.3.0 exceptions-0.10.1-7EeRXpdm0c5D9yRsXefkxH
    filepath-1.4.2.1 haskell-src-exts-1.21.0-CTGpg8A5DVxDxwCwFjhKVU
    monad-loops-0.4.3-EUyUG8IgG57IqzUQzuXocA mtl-2.2.2 text-1.2.3.1
    transformers-0.5.6.2 utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    yaml-0.11.0.0-I079OHGJEsoFIVp9bG1OLv
haddock-interfaces: /usr/share/doc/hindent/html/hindent.haddock
haddock-html: /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
